# Homechart Python Library

> A python library for your Handy Home Assistant.

[![PyPI version](https://badge.fury.io/py/homechart.svg)](https://badge.fury.io/py/homechart)

This repository contains a python library for interacting with the Homechart API.  This library is automatically generated every release from the API schema of the Homechart server.  See the [API docs](https://web.homechart.app/api/docs) for more information.

Please report any issues using the feedback or support buttons in Homechart.
